from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CfDeltaCls:
	"""CfDelta commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cfDelta", core, parent)

	@property
	def ledState(self):
		"""ledState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ledState'):
			from .LedState import LedStateCls
			self._ledState = LedStateCls(self._core, self._cmd_group)
		return self._ledState

	def set(self, cf_delta: float) -> None:
		"""SCPI: CONFigure:CFReduction:CFDelta \n
		Snippet: driver.applications.k18AmplifierEt.configure.cfReduction.cfDelta.set(cf_delta = 1.0) \n
		Sets the value difference by which you want to change the crest factor. \n
			:param cf_delta: numeric value Unit: dB
		"""
		param = Conversions.decimal_value_to_str(cf_delta)
		self._core.io.write(f'CONFigure:CFReduction:CFDelta {param}')

	def get(self) -> float:
		"""SCPI: CONFigure:CFReduction:CFDelta \n
		Snippet: value: float = driver.applications.k18AmplifierEt.configure.cfReduction.cfDelta.get() \n
		Sets the value difference by which you want to change the crest factor. \n
			:return: cf_delta: numeric value Unit: dB"""
		response = self._core.io.query_str(f'CONFigure:CFReduction:CFDelta?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'CfDeltaCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CfDeltaCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StartCls:
	"""Start commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("start", core, parent)

	def set(self, frequency: float, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>[:FREQuency]:STARt \n
		Snippet: driver.sense.espectrum.range.frequency.start.set(frequency = 1.0, subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default) \n
		This command defines the start frequency of a SEM range. Make sure to set an appropriate span. If you set a span that is
			INTRO_CMD_HELP: Note the following prerequisites for the selected transducer: \n
			- smaller than the span the SEM sweep list covers, the R&S FSW will not measure the ranges that are outside the span - results may be invalid.
			- greater than the span the SEM sweep list covers, the R&S FSW will adjust the start frequency of the first SEM range and the stop frequency of the last SEM range to the span
		For more information see 'Ranges and range settings'. \n
			:param frequency: Numeric value. Note that the minimum frequency range of a SEM range is 20 Hz. Unit: Hz
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		param = Conversions.decimal_value_to_str(frequency)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:FREQuency:STARt {param}')

	def get(self, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default) -> float:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>[:FREQuency]:STARt \n
		Snippet: value: float = driver.sense.espectrum.range.frequency.start.get(subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default) \n
		This command defines the start frequency of a SEM range. Make sure to set an appropriate span. If you set a span that is
			INTRO_CMD_HELP: Note the following prerequisites for the selected transducer: \n
			- smaller than the span the SEM sweep list covers, the R&S FSW will not measure the ranges that are outside the span - results may be invalid.
			- greater than the span the SEM sweep list covers, the R&S FSW will adjust the start frequency of the first SEM range and the stop frequency of the last SEM range to the span
		For more information see 'Ranges and range settings'. \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:return: frequency: Numeric value. Note that the minimum frequency range of a SEM range is 20 Hz. Unit: Hz"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		response = self._core.io.query_str(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:FREQuency:STARt?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DrsCls:
	"""Drs commands group definition. 9 total commands, 9 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("drs", core, parent)

	@property
	def aocc(self):
		"""aocc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_aocc'):
			from .Aocc import AoccCls
			self._aocc = AoccCls(self._core, self._cmd_group)
		return self._aocc

	@property
	def dsShift(self):
		"""dsShift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dsShift'):
			from .DsShift import DsShiftCls
			self._dsShift = DsShiftCls(self._core, self._cmd_group)
		return self._dsShift

	@property
	def enpr(self):
		"""enpr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_enpr'):
			from .Enpr import EnprCls
			self._enpr = EnprCls(self._core, self._cmd_group)
		return self._enpr

	@property
	def grpHopping(self):
		"""grpHopping commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_grpHopping'):
			from .GrpHopping import GrpHoppingCls
			self._grpHopping = GrpHoppingCls(self._core, self._cmd_group)
		return self._grpHopping

	@property
	def ndmrs(self):
		"""ndmrs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ndmrs'):
			from .Ndmrs import NdmrsCls
			self._ndmrs = NdmrsCls(self._core, self._cmd_group)
		return self._ndmrs

	@property
	def plid(self):
		"""plid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_plid'):
			from .Plid import PlidCls
			self._plid = PlidCls(self._core, self._cmd_group)
		return self._plid

	@property
	def pucch(self):
		"""pucch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pucch'):
			from .Pucch import PucchCls
			self._pucch = PucchCls(self._core, self._cmd_group)
		return self._pucch

	@property
	def pusch(self):
		"""pusch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pusch'):
			from .Pusch import PuschCls
			self._pusch = PuschCls(self._core, self._cmd_group)
		return self._pusch

	@property
	def seqHopping(self):
		"""seqHopping commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_seqHopping'):
			from .SeqHopping import SeqHoppingCls
			self._seqHopping = SeqHoppingCls(self._core, self._cmd_group)
		return self._seqHopping

	def clone(self) -> 'DrsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DrsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TableCls:
	"""Table commands group definition. 4 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("table", core, parent)

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def listPy(self):
		"""listPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	def delete(self, table_name: str) -> None:
		"""SCPI: [SENSe]:CORRection:LOSS:OUTPut:TABLe:DELete \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.loss.output.table.delete(table_name = '1') \n
		No command help available \n
			:param table_name: No help available
		"""
		param = Conversions.value_to_quoted_str(table_name)
		self._core.io.write(f'SENSe:CORRection:LOSS:OUTPut:TABLe:DELete {param}')

	def clone(self) -> 'TableCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TableCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	def set(self, power: float, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:MIXer[:POWer] \n
		Snippet: driver.inputPy.mixer.power.set(power = 1.0, inputIx = repcap.InputIx.Default) \n
		No command help available \n
			:param power: No help available
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.decimal_value_to_str(power)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:MIXer:POWer {param}')

	def get(self, inputIx=repcap.InputIx.Default) -> float:
		"""SCPI: INPut<ip>:MIXer[:POWer] \n
		Snippet: value: float = driver.inputPy.mixer.power.get(inputIx = repcap.InputIx.Default) \n
		No command help available \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: power: No help available"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:MIXer:POWer?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class XcorrCls:
	"""Xcorr commands group definition. 32 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("xcorr", core, parent)

	@property
	def mlobe(self):
		"""mlobe commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_mlobe'):
			from .Mlobe import MlobeCls
			self._mlobe = MlobeCls(self._core, self._cmd_group)
		return self._mlobe

	@property
	def nmse(self):
		"""nmse commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_nmse'):
			from .Nmse import NmseCls
			self._nmse = NmseCls(self._core, self._cmd_group)
		return self._nmse

	@property
	def slobe(self):
		"""slobe commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_slobe'):
			from .Slobe import SlobeCls
			self._slobe = SlobeCls(self._core, self._cmd_group)
		return self._slobe

	def clone(self) -> 'XcorrCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = XcorrCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BoundaryCls:
	"""Boundary commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("boundary", core, parent)

	def get(self, window=repcap.Window.Default) -> str:
		"""SCPI: TRACe<n>:IQ:SCAPture:BOUNdary \n
		Snippet: value: str = driver.applications.k6Pulse.trace.iq.scapture.boundary.get(window = repcap.Window.Default) \n
		This remote control command returns an array of sample indices for the start of each captured data segment. The length of
		the array depends on the number of trigger events specified by [SENSe:]SWEep:SCAPture:EVENts. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trace')
			:return: data: 1..n Window"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'TRACe{window_cmd_val}:IQ:SCAPture:BOUNdary?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OevmCls:
	"""Oevm commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("oevm", core, parent)

	def set(self, optimisation: enums.OptimisationOevm) -> None:
		"""SCPI: CONFigure:POWer:AUTO:OEVM \n
		Snippet: driver.applications.k91Wlan.configure.power.auto.oevm.set(optimisation = enums.OptimisationOevm.FULL) \n
		Defines whether an optional iterative search is performed to determine the required settings for minimum residual EVM. If
		enabled, the required reference level, preamplifier and, optionally, attenuation are configured. method RsFsw.
		Applications.K91_Wlan.Configure.Power.Auto.set is set to 'OFF'. \n
			:param optimisation: OFF | PAONly | FULL OFF (Default) : No optimization performed FULL An optional iterative search for minimum residual EVM is performed for the available preamplifier and attenuation settings. The optimal settings are configured. PAONly An optional iterative search for minimum residual EVM is performed, but only the available preamplifier settings are considered during the search. The optimal settings are configured.
		"""
		param = Conversions.enum_scalar_to_str(optimisation, enums.OptimisationOevm)
		self._core.io.write(f'CONFigure:POWer:AUTO:OEVM {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.OptimisationOevm:
		"""SCPI: CONFigure:POWer:AUTO:OEVM \n
		Snippet: value: enums.OptimisationOevm = driver.applications.k91Wlan.configure.power.auto.oevm.get() \n
		Defines whether an optional iterative search is performed to determine the required settings for minimum residual EVM. If
		enabled, the required reference level, preamplifier and, optionally, attenuation are configured. method RsFsw.
		Applications.K91_Wlan.Configure.Power.Auto.set is set to 'OFF'. \n
			:return: optimisation: OFF | PAONly | FULL OFF (Default) : No optimization performed FULL An optional iterative search for minimum residual EVM is performed for the available preamplifier and attenuation settings. The optimal settings are configured. PAONly An optional iterative search for minimum residual EVM is performed, but only the available preamplifier settings are considered during the search. The optimal settings are configured."""
		response = self._core.io.query_str(f'CONFigure:POWer:AUTO:OEVM?')
		return Conversions.str_to_scalar_enum(response, enums.OptimisationOevm)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ColumnCls:
	"""Column commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("column", core, parent)

	def set(self, state: bool, headers: List[enums.TableHeadersK60] = None, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:CHRDetection:TABLe:COLumn \n
		Snippet: driver.applications.k60Transient.calculate.chrDetection.table.column.set(state = False, headers = [TableHeadersK60.ALL, TableHeadersK60.SWITching], window = repcap.Window.Default) \n
		This command enables or disables columns in all chirp results and statistics tables. Note that only the enabled columns
		are returned for the method RsFsw.Applications.K60_Transient.Calculate.ChrDetection.Table.Results.get_ query. \n
			:param state: ON | OFF | 1 | 0 Enables or disables all subsequently listed headers ON | 1 Provides results for the defined Headers only OFF | 0 Provides results for all table parameters except the specified Headers.
			:param headers: ALL | STATe | BEGin | LENGth | RATE | CHERror | FREQuency | MAXFm | RMSFm | AVGFm | MINPower | MAXPower | AVGPower | PWRRipple | AVPHm | MXPHm | RMSPm | FMSPoint | FMSTime | FMSLength | BWIDth | AVGNonlinear | RMSNonlinear | MAXNonlinear | PMSPoint | PMSTime | PMSLength All listed parameters are displayed or hidden in the table results (depending on the State parameter) . ALL See 'Chirp parameters'. STATe Chirp state BEGin Chirp Begin LENGth Chirp length RATe Chirp rate CHERror Chirp state deviation FREQuency Average frequency MAXFm Maximum Frequency Deviation RMSFm RMS Frequency Deviation AVGFm Average Frequency Deviation AVGPower Average power MINPower Minimum power MAXPower Maximum power PWRRipple Power ripple AVPHm Average phase deviation MXPHm Maximum phase deviation RMSPm RMS phase deviation FMSPoint FM settling point FMSTime FM settling time FMSLength FM settled length BWIDth Bandwidth AVGNonlinear Average frequency non-linearity RMSNonlinear RMS frequency non-linearity MAXNonlinear Peak frequency non-linearity PMSPoint PM settling point PMSTime PM settling time PMSLength PM settled length
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('state', state, DataType.Boolean), ArgSingle('headers', headers, DataType.EnumList, enums.TableHeadersK60, True, True, 1))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:CHRDetection:TABLe:COLumn {param}'.rstrip())

	# noinspection PyTypeChecker
	class ColumnStruct(StructBase):
		"""Response structure. Fields: \n
			- State: bool: ON | OFF | 1 | 0 Enables or disables all subsequently listed headers ON | 1 Provides results for the defined Headers only OFF | 0 Provides results for all table parameters except the specified Headers.
			- Headers: List[enums.TableHeadersK60]: ALL | STATe | BEGin | LENGth | RATE | CHERror | FREQuency | MAXFm | RMSFm | AVGFm | MINPower | MAXPower | AVGPower | PWRRipple | AVPHm | MXPHm | RMSPm | FMSPoint | FMSTime | FMSLength | BWIDth | AVGNonlinear | RMSNonlinear | MAXNonlinear | PMSPoint | PMSTime | PMSLength All listed parameters are displayed or hidden in the table results (depending on the State parameter) . ALL See 'Chirp parameters'. STATe Chirp state BEGin Chirp Begin LENGth Chirp length RATe Chirp rate CHERror Chirp state deviation FREQuency Average frequency MAXFm Maximum Frequency Deviation RMSFm RMS Frequency Deviation AVGFm Average Frequency Deviation AVGPower Average power MINPower Minimum power MAXPower Maximum power PWRRipple Power ripple AVPHm Average phase deviation MXPHm Maximum phase deviation RMSPm RMS phase deviation FMSPoint FM settling point FMSTime FM settling time FMSLength FM settled length BWIDth Bandwidth AVGNonlinear Average frequency non-linearity RMSNonlinear RMS frequency non-linearity MAXNonlinear Peak frequency non-linearity PMSPoint PM settling point PMSTime PM settling time PMSLength PM settled length"""
		__meta_args_list = [
			ArgStruct.scalar_bool('State'),
			ArgStruct('Headers', DataType.EnumList, enums.TableHeadersK60, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.State: bool = None
			self.Headers: List[enums.TableHeadersK60] = None

	def get(self, window=repcap.Window.Default) -> ColumnStruct:
		"""SCPI: CALCulate<n>:CHRDetection:TABLe:COLumn \n
		Snippet: value: ColumnStruct = driver.applications.k60Transient.calculate.chrDetection.table.column.get(window = repcap.Window.Default) \n
		This command enables or disables columns in all chirp results and statistics tables. Note that only the enabled columns
		are returned for the method RsFsw.Applications.K60_Transient.Calculate.ChrDetection.Table.Results.get_ query. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: structure: for return value, see the help for ColumnStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:CHRDetection:TABLe:COLumn?', self.__class__.ColumnStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PositionCls:
	"""Position commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("position", core, parent)

	def set(self, position: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:MATH:POSition \n
		Snippet: driver.calculate.math.position.set(position = 1.0, window = repcap.Window.Default) \n
		This command defines the position of the trace resulting from the mathematical operation. \n
			:param position: Vertical position of the trace in % of the height of the diagram area. 100 PCT corresponds to the upper diagram border. Range: -100 to 200, Unit: PCT
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(position)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:MATH:POSition {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:MATH:POSition \n
		Snippet: value: float = driver.calculate.math.position.get(window = repcap.Window.Default) \n
		This command defines the position of the trace resulting from the mathematical operation. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: position: Vertical position of the trace in % of the height of the diagram area. 100 PCT corresponds to the upper diagram border. Range: -100 to 200, Unit: PCT"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MATH:POSition?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, data: float) -> None:
		"""SCPI: [SENSe]:CORRection:CVL:DATA \n
		Snippet: driver.applications.k70Vsa.sense.correction.cvl.data.set(data = 1.0) \n
		This command defines the reference values of the selected conversion loss tables. The values are entered as a set of
		frequency/level pairs. A maximum of 50 frequency/level pairs may be entered. Before this command can be performed, the
		conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only available with option
		B21 (External Mixer) installed. \n
			:param data: No help available
		"""
		param = Conversions.decimal_value_to_str(data)
		self._core.io.write(f'SENSe:CORRection:CVL:DATA {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CORRection:CVL:DATA \n
		Snippet: value: float = driver.applications.k70Vsa.sense.correction.cvl.data.get() \n
		This command defines the reference values of the selected conversion loss tables. The values are entered as a set of
		frequency/level pairs. A maximum of 50 frequency/level pairs may be entered. Before this command can be performed, the
		conversion loss table must be selected (see [SENSe:]CORRection:CVL:SELect) . This command is only available with option
		B21 (External Mixer) installed. \n
			:return: data: No help available"""
		response = self._core.io.query_str(f'SENSe:CORRection:CVL:DATA?')
		return Conversions.str_to_float(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SspacingCls:
	"""Sspacing commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sspacing", core, parent)

	def set(self, subcarrier_spacing: enums.SubcarrierSpacing, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:UL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SSPacing \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.uplink.cc.frame.bwPart.sspacing.set(subcarrier_spacing = enums.SubcarrierSpacing.SS120, carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default) \n
		This command selects the subcarrier spacing of a bandwidth part. \n
			:param subcarrier_spacing: SS15 15 kHz subcarrier spacing. Only for signal deployment in FR1. SS30 30 kHz subcarrier spacing. Only for signal deployment in FR1. SS60 60 kHz subcarrier spacing with normal cyclic prefix. For all signal deployments. SS120 120 kHz subcarrier spacing. Only for signal deployment in FR2. SS480 480 kHz subcarrier spacing. Only for signal deployment in FR2-2. SS960 960 kHz subcarrier spacing. Only for signal deployment in FR2-2 and a 2000 MHz bandwidth. X60 60 kHz subcarrier spacing with extended cyclic prefix. For all signal deployments.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
		"""
		param = Conversions.enum_scalar_to_str(subcarrier_spacing, enums.SubcarrierSpacing)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		self._core.io.write(f'CONFigure:NR5G:UL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SSPacing {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default, bwPart=repcap.BwPart.Default) -> enums.SubcarrierSpacing:
		"""SCPI: CONFigure[:NR5G]:UL[:CC<cc>]:FRAMe<fr>:BWPart<bwp>:SSPacing \n
		Snippet: value: enums.SubcarrierSpacing = driver.applications.k14Xnr5G.configure.nr5G.uplink.cc.frame.bwPart.sspacing.get(carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default, bwPart = repcap.BwPart.Default) \n
		This command selects the subcarrier spacing of a bandwidth part. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param bwPart: optional repeated capability selector. Default value: Nr1 (settable in the interface 'BwPart')
			:return: subcarrier_spacing: SS15 15 kHz subcarrier spacing. Only for signal deployment in FR1. SS30 30 kHz subcarrier spacing. Only for signal deployment in FR1. SS60 60 kHz subcarrier spacing with normal cyclic prefix. For all signal deployments. SS120 120 kHz subcarrier spacing. Only for signal deployment in FR2. SS480 480 kHz subcarrier spacing. Only for signal deployment in FR2-2. SS960 960 kHz subcarrier spacing. Only for signal deployment in FR2-2 and a 2000 MHz bandwidth. X60 60 kHz subcarrier spacing with extended cyclic prefix. For all signal deployments."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		bwPart_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPart, repcap.BwPart)
		response = self._core.io.query_str(f'CONFigure:NR5G:UL:CC{carrierComponent_cmd_val}:FRAMe{frame_cmd_val}:BWPart{bwPart_cmd_val}:SSPacing?')
		return Conversions.str_to_scalar_enum(response, enums.SubcarrierSpacing)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal.Utilities import trim_str_response
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, carrierComponent=repcap.CarrierComponent.Default, frame=repcap.Frame.Default) -> str:
		"""SCPI: CALCulate<n>:LIMit<li>[:CC<cc>][:ISRC][:FRAMe<fr>]:SUMMary:EVM:DSST:MINimum:RESult \n
		Snippet: value: str = driver.applications.k14Xnr5G.calculate.limit.cc.isrc.frame.summary.evm.dsst.minimum.result.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, carrierComponent = repcap.CarrierComponent.Default, frame = repcap.Frame.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:param frame: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:return: limit_check: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		frame_cmd_val = self._cmd_group.get_repcap_cmd_value(frame, repcap.Frame)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:CC{carrierComponent_cmd_val}:ISRC:FRAMe{frame_cmd_val}:SUMMary:EVM:DSST:MINimum:RESult?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LedStateCls:
	"""LedState commands group definition. 1 total commands, 0 Subgroups, 1 group commands
	Repeated Capability: Instrument, default value after init: Instrument.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ledState", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_instrument_get', 'repcap_instrument_set', repcap.Instrument.Nr1)

	def repcap_instrument_set(self, instrument: repcap.Instrument) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Instrument.Default
		Default value after init: Instrument.Nr1"""
		self._cmd_group.set_repcap_enum_value(instrument)

	def repcap_instrument_get(self) -> repcap.Instrument:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	# noinspection PyTypeChecker
	def get(self, instrument=repcap.Instrument.Default) -> enums.LedState:
		"""SCPI: CONFigure[:LTE]:ANTMatrix:LEDState<in> \n
		Snippet: value: enums.LedState = driver.applications.k10Xlte.configure.lte.antMatrix.ledState.get(instrument = repcap.Instrument.Default) \n
		This command queries the state of one of the instruments in a MIMO setup. \n
			:param instrument: optional repeated capability selector. Default value: Nr1 (settable in the interface 'LedState')
			:return: color: GREEN Connection to the instrument has been successfully established. GREY Instrument connection has been turned off with method RsFsw.Applications.K10x_Lte.Configure.Lte.AntMatrix.State.set. RED Connection to the instrument could not be established."""
		instrument_cmd_val = self._cmd_group.get_repcap_cmd_value(instrument, repcap.Instrument)
		response = self._core.io.query_str(f'CONFigure:LTE:ANTMatrix:LEDState{instrument_cmd_val}?')
		return Conversions.str_to_scalar_enum(response, enums.LedState)

	def clone(self) -> 'LedStateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LedStateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DateCls:
	"""Date commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("date", core, parent)

	def set(self, date: str) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:ALIGnment:DATE \n
		Snippet: driver.system.communicate.rdevice.oscilloscope.alignment.date.set(date = '1') \n
		Returns the date of alignment of the 'IF OUT 2 GHz/ IF OUT 5 GHz' to the oscilloscope for the optional 2 GHz / 5 GHz
		bandwidth extension (R&S FSW-B2000/B5000) . For details see 'Alignment'. The alignment data is stored separately for
		common B2000/B5000 mode and power splitter mode. The returned date refers to the alignment of the currently active mode. \n
			:param date: Returns the date of alignment.
		"""
		param = Conversions.value_to_quoted_str(date)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:ALIGnment:DATE {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:ALIGnment:DATE \n
		Snippet: value: str = driver.system.communicate.rdevice.oscilloscope.alignment.date.get() \n
		Returns the date of alignment of the 'IF OUT 2 GHz/ IF OUT 5 GHz' to the oscilloscope for the optional 2 GHz / 5 GHz
		bandwidth extension (R&S FSW-B2000/B5000) . For details see 'Alignment'. The alignment data is stored separately for
		common B2000/B5000 mode and power splitter mode. The returned date refers to the alignment of the currently active mode. \n
			:return: date: Returns the date of alignment."""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:ALIGnment:DATE?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HoldoffCls:
	"""Holdoff commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("holdoff", core, parent)

	def set(self, time: float) -> None:
		"""SCPI: TRIGger[:SEQuence]:RFPower:HOLDoff \n
		Snippet: driver.applications.k17Mcgd.trigger.sequence.rfPower.holdoff.set(time = 1.0) \n
		This command defines the holding time before the next trigger event. Note that this command is available for any trigger
		source, not just RF Power. Note that this command is maintained for compatibility reasons only. Use the method RsFsw.
		Applications.K10x_Lte.Trigger.Sequence.IfPower.Holdoff.set command for new remote control programs. \n
			:param time: Unit: S
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'TRIGger:SEQuence:RFPower:HOLDoff {param}')

	def get(self) -> float:
		"""SCPI: TRIGger[:SEQuence]:RFPower:HOLDoff \n
		Snippet: value: float = driver.applications.k17Mcgd.trigger.sequence.rfPower.holdoff.get() \n
		This command defines the holding time before the next trigger event. Note that this command is available for any trigger
		source, not just RF Power. Note that this command is maintained for compatibility reasons only. Use the method RsFsw.
		Applications.K10x_Lte.Trigger.Sequence.IfPower.Holdoff.set command for new remote control programs. \n
			:return: time: Unit: S"""
		response = self._core.io.query_str(f'TRIGger:SEQuence:RFPower:HOLDoff?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def get(self) -> str:
		"""SCPI: FETCh:SFIeld:ALL \n
		Snippet: value: str = driver.applications.k91Wlan.fetch.sfield.all.get() \n
		Returns the results of the Signal Fields table, including column headers. The result is a comma-separated list of values
		for the selected PPDU. For details on the provided information see 'Signal Field' This command is only available for the
		IEEE 802.11ax, be standards. For other standards, see method RsFsw.Trace.Data.get_. \n
			:return: result: Signal_field_type[,Occupied_bits,Field_name, Binary_value,Human_readable_value],..."""
		response = self._core.io.query_str(f'FETCh:SFIeld:ALL?')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NormaliseCls:
	"""Normalise commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("normalise", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: CONFigure:WLAN:SMAPping:NORMalise \n
		Snippet: driver.applications.k91Wlan.configure.wlan.smapping.normalise.set(state = False) \n
		This remote control command specifies whether an amplification of the signal power due to the spatial mapping is
		performed according to the matrix entries. If this command it set to ON then the spatial mapping matrix is scaled by a
		constant factor to obtain a passive spatial mapping matrix which does not increase the total transmitted power. If this
		command is set to OFF the normalization step is omitted. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CONFigure:WLAN:SMAPping:NORMalise {param}')

	def get(self) -> bool:
		"""SCPI: CONFigure:WLAN:SMAPping:NORMalise \n
		Snippet: value: bool = driver.applications.k91Wlan.configure.wlan.smapping.normalise.get() \n
		This remote control command specifies whether an amplification of the signal power due to the spatial mapping is
		performed according to the matrix entries. If this command it set to ON then the spatial mapping matrix is scaled by a
		constant factor to obtain a passive spatial mapping matrix which does not increase the total transmitted power. If this
		command is set to OFF the normalization step is omitted. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		response = self._core.io.query_str(f'CONFigure:WLAN:SMAPping:NORMalise?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: MMEMory:LOAD:SEM:STATe \n
		Snippet: driver.applications.k91Wlan.massMemory.load.sem.state.set(filename = '1') \n
		This command loads a spectrum emission mask setup from an xml file. Note that this command is maintained for
		compatibility reasons only. Use the SENS:ESP:PRES command for new remote control programs.
		(See [SENSe:]ESPectrum<sb>:PRESet[:STANdard]) . See the R&S FSW User Manual, 'Remote commands for SEM measurements'
		chapter. \n
			:param filename: string Path and name of the .xml file that contains the SEM setup information.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write_with_opc(f'MMEMory:LOAD:SEM:STATe 1, {param}')



"""RsFsw instrument driver
	:version: 5.20.1.214
	:copyright: 2021 by Rohde & Schwarz GMBH & Co. KG
	:license: MIT, see LICENSE for more details.
"""

__version__ = '5.20.1.214'

# Main class
from RsFsw.RsFsw import RsFsw

# Bin data format
from RsFsw.Internal.Conversions import BinIntFormat, BinFloatFormat

# Exceptions
from RsFsw.Internal.InstrumentErrors import RsInstrException, TimeoutException, StatusException, UnexpectedResponseException, ResourceError, DriverValueError

# Callback Event Argument prototypes
from RsFsw.Internal.IoTransferEventArgs import IoTransferEventArgs

# Logging Mode
from RsFsw.Internal.ScpiLogger import LoggingMode

# enums
from RsFsw import enums

# repcaps
from RsFsw import repcap



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AverageCls:
	"""Average commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("average", core, parent)

	def get(self) -> str:
		"""SCPI: FETCh:BURSt:CFERror:AVERage \n
		Snippet: value: str = driver.applications.k91Wlan.fetch.burst.cfError.average.get() \n
		This command returns the average, maximum or minimum center frequency errors in Hertz. For details see 'Modulation
		accuracy, flatness and tolerance parameters'. \n
			:return: result: Global Result, Stream 1 result ... Stream n result"""
		response = self._core.io.query_str(f'FETCh:BURSt:CFERror:AVERage?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LengthsCls:
	"""Lengths commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lengths", core, parent)

	def get(self) -> str:
		"""SCPI: FETCh:BURSt:LENGths \n
		Snippet: value: str = driver.applications.k9X11Ad.fetch.burst.lengths.get() \n
		This command returns the EVM symbol count of the analyzed PPDUs from the current measurement.
		The result is a comma-separated list of symbol counts, one for each PPDU. \n
			:return: ppdu_length: integer value number of symbols as counted for the EVM calculation"""
		response = self._core.io.query_str(f'FETCh:BURSt:LENGths?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CrosstalkCls:
	"""Crosstalk commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("crosstalk", core, parent)

	def set(self, crosstalk: bool) -> None:
		"""SCPI: CONFigure[:NR5G]:DL:MIMO:CROSstalk \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.downlink.mimo.crosstalk.set(crosstalk = False) \n
		No command help available \n
			:param crosstalk: No help available
		"""
		param = Conversions.bool_to_str(crosstalk)
		self._core.io.write(f'CONFigure:NR5G:DL:MIMO:CROSstalk {param}')

	def get(self) -> bool:
		"""SCPI: CONFigure[:NR5G]:DL:MIMO:CROSstalk \n
		Snippet: value: bool = driver.applications.k14Xnr5G.configure.nr5G.downlink.mimo.crosstalk.get() \n
		No command help available \n
			:return: crosstalk: No help available"""
		response = self._core.io.query_str(f'CONFigure:NR5G:DL:MIMO:CROSstalk?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, source: enums.BbInputSource, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<Undef>[:SELect] \n
		Snippet: driver.applications.k91Wlan.inputPy.select.set(source = enums.BbInputSource.AIQ, inputIx = repcap.InputIx.Default) \n
		This command selects the signal source for measurements, i.e. it defines which connector is used to input data to the R&S
		FSW. If no additional input options are installed, only RF input or file input is supported. For R&S FSW85 models with
		two RF input connectors, you must select the input connector to configure first using method RsFsw.Applications.K10x_Lte.
		InputPy.TypePy.set. Tip: The I/Q data to be analyzed for WLAN 802.11 cannot only be measured by the R&S FSW WLAN
		application itself, it can also be imported to the application, provided it has the correct format. Furthermore, the
		analyzed I/Q data from the R&S FSW WLAN application can be exported for further analysis in external applications.
		For details, see the R&S FSW I/Q Analyzer and I/Q Input User Manual. \n
			:param source: RF Radio Frequency ('RF INPUT' connector) FIQ I/Q data file (selected by method RsFsw.InputPy.File.Path.set) For details, see 'Basics on input from I/Q data files'. Not available for Input2. DIQ Digital IQ data (only available with optional 'Digital Baseband' interface) For details on I/Q input see 'Digital Input'. Not available for Input2. AIQ Analog Baseband signal (only available with optional 'Analog Baseband' interface R&S FSW-B71) For details on Analog Baseband input, see 'Processing Data From the Analog Baseband Interface'. Not available for Input2.
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(source, enums.BbInputSource)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:SELect {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.BbInputSource:
		"""SCPI: INPut<Undef>[:SELect] \n
		Snippet: value: enums.BbInputSource = driver.applications.k91Wlan.inputPy.select.get(inputIx = repcap.InputIx.Default) \n
		This command selects the signal source for measurements, i.e. it defines which connector is used to input data to the R&S
		FSW. If no additional input options are installed, only RF input or file input is supported. For R&S FSW85 models with
		two RF input connectors, you must select the input connector to configure first using method RsFsw.Applications.K10x_Lte.
		InputPy.TypePy.set. Tip: The I/Q data to be analyzed for WLAN 802.11 cannot only be measured by the R&S FSW WLAN
		application itself, it can also be imported to the application, provided it has the correct format. Furthermore, the
		analyzed I/Q data from the R&S FSW WLAN application can be exported for further analysis in external applications.
		For details, see the R&S FSW I/Q Analyzer and I/Q Input User Manual. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: source: RF Radio Frequency ('RF INPUT' connector) FIQ I/Q data file (selected by method RsFsw.InputPy.File.Path.set) For details, see 'Basics on input from I/Q data files'. Not available for Input2. DIQ Digital IQ data (only available with optional 'Digital Baseband' interface) For details on I/Q input see 'Digital Input'. Not available for Input2. AIQ Analog Baseband signal (only available with optional 'Analog Baseband' interface R&S FSW-B71) For details on Analog Baseband input, see 'Processing Data From the Analog Baseband Interface'. Not available for Input2."""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:SELect?')
		return Conversions.str_to_scalar_enum(response, enums.BbInputSource)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CalculateCls:
	"""Calculate commands group definition. 301 total commands, 13 Subgroups, 0 group commands
	Repeated Capability: Window, default value after init: Window.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("calculate", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_window_get', 'repcap_window_set', repcap.Window.Nr1)

	def repcap_window_set(self, window: repcap.Window) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Window.Default
		Default value after init: Window.Nr1"""
		self._cmd_group.set_repcap_enum_value(window)

	def repcap_window_get(self) -> repcap.Window:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def distribution(self):
		"""distribution commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_distribution'):
			from .Distribution import DistributionCls
			self._distribution = DistributionCls(self._core, self._cmd_group)
		return self._distribution

	@property
	def unit(self):
		"""unit commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_unit'):
			from .Unit import UnitCls
			self._unit = UnitCls(self._core, self._cmd_group)
		return self._unit

	@property
	def deltaMarker(self):
		"""deltaMarker commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_deltaMarker'):
			from .DeltaMarker import DeltaMarkerCls
			self._deltaMarker = DeltaMarkerCls(self._core, self._cmd_group)
		return self._deltaMarker

	@property
	def marker(self):
		"""marker commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_marker'):
			from .Marker import MarkerCls
			self._marker = MarkerCls(self._core, self._cmd_group)
		return self._marker

	@property
	def msra(self):
		"""msra commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_msra'):
			from .Msra import MsraCls
			self._msra = MsraCls(self._core, self._cmd_group)
		return self._msra

	@property
	def rtms(self):
		"""rtms commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_rtms'):
			from .Rtms import RtmsCls
			self._rtms = RtmsCls(self._core, self._cmd_group)
		return self._rtms

	@property
	def ar(self):
		"""ar commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ar'):
			from .Ar import ArCls
			self._ar = ArCls(self._core, self._cmd_group)
		return self._ar

	@property
	def hopDetection(self):
		"""hopDetection commands group. 14 Sub-classes, 0 commands."""
		if not hasattr(self, '_hopDetection'):
			from .HopDetection import HopDetectionCls
			self._hopDetection = HopDetectionCls(self._core, self._cmd_group)
		return self._hopDetection

	@property
	def chrDetection(self):
		"""chrDetection commands group. 14 Sub-classes, 0 commands."""
		if not hasattr(self, '_chrDetection'):
			from .ChrDetection import ChrDetectionCls
			self._chrDetection = ChrDetectionCls(self._core, self._cmd_group)
		return self._chrDetection

	@property
	def result(self):
		"""result commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_result'):
			from .Result import ResultCls
			self._result = ResultCls(self._core, self._cmd_group)
		return self._result

	@property
	def spectrogram(self):
		"""spectrogram commands group. 4 Sub-classes, 2 commands."""
		if not hasattr(self, '_spectrogram'):
			from .Spectrogram import SpectrogramCls
			self._spectrogram = SpectrogramCls(self._core, self._cmd_group)
		return self._spectrogram

	@property
	def trace(self):
		"""trace commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	@property
	def trend(self):
		"""trend commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_trend'):
			from .Trend import TrendCls
			self._trend = TrendCls(self._core, self._cmd_group)
		return self._trend

	def clone(self) -> 'CalculateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CalculateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdCls:
	"""Id commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("id", core, parent)

	def get(self, query_range: enums.SelectionRangeB) -> str:
		"""SCPI: [SENSe]:CHIRp:ID \n
		Snippet: value: str = driver.applications.k60Transient.sense.chirp.id.get(query_range = enums.SelectionRangeB.ALL) \n
		Returns the chirp IDs from the Results table for the specified chirp(s) . \n
			:param query_range: CURRent | ALL CURRent Detected chirps in the current capture buffer ALL All chirps detected in the entire measurement
			:return: result: char_data"""
		param = Conversions.enum_scalar_to_str(query_range, enums.SelectionRangeB)
		response = self._core.io.query_str(f'SENSe:CHIRp:ID? {param}')
		return trim_str_response(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UplinkCls:
	"""Uplink commands group definition. 72 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uplink", core, parent)

	@property
	def cabw(self):
		"""cabw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cabw'):
			from .Cabw import CabwCls
			self._cabw = CabwCls(self._core, self._cmd_group)
		return self._cabw

	@property
	def bdSource(self):
		"""bdSource commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bdSource'):
			from .BdSource import BdSourceCls
			self._bdSource = BdSourceCls(self._core, self._cmd_group)
		return self._bdSource

	@property
	def cc(self):
		"""cc commands group. 17 Sub-classes, 0 commands."""
		if not hasattr(self, '_cc'):
			from .Cc import CcCls
			self._cc = CcCls(self._core, self._cmd_group)
		return self._cc

	def clone(self) -> 'UplinkCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = UplinkCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffPowerCls:
	"""OffPower commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offPower", core, parent)

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> str:
		"""SCPI: CALCulate<n>:LIMit<li>:OOPower:OFFPower \n
		Snippet: value: str = driver.applications.k10Xlte.calculate.limit.ooPower.offPower.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command queries the results of the limit check in the 'Off' periods of On/Off Power measurements. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: results: Returns one value for every 'Off' period. PASSED Limit check has passed. FAILED Limit check has failed."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:OOPower:OFFPower?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class VideoCls:
	"""Video commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("video", core, parent)

	def set(self, vbw: float, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:BANDwidth:VIDeo \n
		Snippet: driver.sense.listPy.range.bandwidth.video.set(vbw = 1.0, rangePy = repcap.RangePy.Default) \n
		This command defines the video bandwidth for a spurious emission measurement range. The sweep list cannot be configured
		using remote commands during an on-going sweep operation. \n
			:param vbw: Video bandwidth. Refer to the data sheet for available video bandwidths. Unit: Hz
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		param = Conversions.decimal_value_to_str(vbw)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:LIST:RANGe{rangePy_cmd_val}:BANDwidth:VIDeo {param}')

	def get(self, rangePy=repcap.RangePy.Default) -> float:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:BANDwidth:VIDeo \n
		Snippet: value: float = driver.sense.listPy.range.bandwidth.video.get(rangePy = repcap.RangePy.Default) \n
		This command defines the video bandwidth for a spurious emission measurement range. The sweep list cannot be configured
		using remote commands during an on-going sweep operation. \n
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:return: vbw: Video bandwidth. Refer to the data sheet for available video bandwidths. Unit: Hz"""
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		response = self._core.io.query_str(f'SENSe:LIST:RANGe{rangePy_cmd_val}:BANDwidth:VIDeo?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def resolution(self):
		"""resolution commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_resolution'):
			from .Resolution import ResolutionCls
			self._resolution = ResolutionCls(self._core, self._cmd_group)
		return self._resolution

	def set(self, arg_0: bool, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<1..16>:COUNt \n
		Snippet: driver.applications.k149Uwb.calculate.marker.count.set(arg_0 = False, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
			:param arg_0: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.bool_to_str(arg_0)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:COUNt {param}')

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> bool:
		"""SCPI: CALCulate<n>:MARKer<1..16>:COUNt \n
		Snippet: value: bool = driver.applications.k149Uwb.calculate.marker.count.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: arg_0: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:COUNt?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'CountCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CountCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, coupling: enums.CouplingRlevel) -> None:
		"""SCPI: CONFigure:WLAN:ANTMatrix:SOURce:RLEVel:OFFSet \n
		Snippet: driver.applications.k91Wlan.configure.wlan.antMatrix.source.refLevel.offset.set(coupling = enums.CouplingRlevel.MANual) \n
		This remote control command determines whether the reference level for the primary and secondary devices in a
		simultaneous MIMO setup are coupled or not. \n
			:param coupling: PRIMary | MANual Coupling mode PRIMary The secondary analyzers' reference levels are set to match that of the primary. MANual The secondary analyzers' reference levels are specified individually (see method RsFsw.Applications.K91_Wlan.Configure.Wlan.AntMatrix.Source.RefLevel.Offset.set) and are not coupled to the reference level offset of the primary analyzer.
		"""
		param = Conversions.enum_scalar_to_str(coupling, enums.CouplingRlevel)
		self._core.io.write(f'CONFigure:WLAN:ANTMatrix:SOURce:RLEVel:OFFSet {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.CouplingRlevel:
		"""SCPI: CONFigure:WLAN:ANTMatrix:SOURce:RLEVel:OFFSet \n
		Snippet: value: enums.CouplingRlevel = driver.applications.k91Wlan.configure.wlan.antMatrix.source.refLevel.offset.get() \n
		This remote control command determines whether the reference level for the primary and secondary devices in a
		simultaneous MIMO setup are coupled or not. \n
			:return: coupling: PRIMary | MANual Coupling mode PRIMary The secondary analyzers' reference levels are set to match that of the primary. MANual The secondary analyzers' reference levels are specified individually (see method RsFsw.Applications.K91_Wlan.Configure.Wlan.AntMatrix.Source.RefLevel.Offset.set) and are not coupled to the reference level offset of the primary analyzer."""
		response = self._core.io.query_str(f'CONFigure:WLAN:ANTMatrix:SOURce:RLEVel:OFFSet?')
		return Conversions.str_to_scalar_enum(response, enums.CouplingRlevel)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PortCls:
	"""Port commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("port", core, parent)

	def set(self, port: enums.Port) -> None:
		"""SCPI: TRIGger[:SEQuence]:PORT \n
		Snippet: driver.applications.k14Xnr5G.trigger.sequence.port.set(port = enums.Port.PORT1) \n
		This command selects the trigger port for measurements with devices that have several trigger ports. \n
			:param port: PORT1 PORT2 PORT3
		"""
		param = Conversions.enum_scalar_to_str(port, enums.Port)
		self._core.io.write(f'TRIGger:SEQuence:PORT {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.Port:
		"""SCPI: TRIGger[:SEQuence]:PORT \n
		Snippet: value: enums.Port = driver.applications.k14Xnr5G.trigger.sequence.port.get() \n
		This command selects the trigger port for measurements with devices that have several trigger ports. \n
			:return: port: PORT1 PORT2 PORT3"""
		response = self._core.io.query_str(f'TRIGger:SEQuence:PORT?')
		return Conversions.str_to_scalar_enum(response, enums.Port)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UaChannelCls:
	"""UaChannel commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uaChannel", core, parent)

	def set(self, alpha: float) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:FILTer:ALPHa:UACHannel \n
		Snippet: driver.sense.power.achannel.filterPy.alpha.uaChannel.set(alpha = 1.0) \n
		This command defines the roll-off factor for the upper adjacent channel weighting filter for asymmetrical MSR signals. To
		configure the factor for the upper adjacent channel, use the [SENSe:]POWer:ACHannel:FILTer:ALPHa:ACHannel command. \n
			:param alpha: Roll-off factor Range: 0 to 1
		"""
		param = Conversions.decimal_value_to_str(alpha)
		self._core.io.write(f'SENSe:POWer:ACHannel:FILTer:ALPHa:UACHannel {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:FILTer:ALPHa:UACHannel \n
		Snippet: value: float = driver.sense.power.achannel.filterPy.alpha.uaChannel.get() \n
		This command defines the roll-off factor for the upper adjacent channel weighting filter for asymmetrical MSR signals. To
		configure the factor for the upper adjacent channel, use the [SENSe:]POWer:ACHannel:FILTer:ALPHa:ACHannel command. \n
			:return: alpha: Roll-off factor Range: 0 to 1"""
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:FILTer:ALPHa:UACHannel?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	def set(self) -> None:
		"""SCPI: SYSTem:CONFigure:GENerator:INITialise[:IMMediate] \n
		Snippet: driver.applications.k30NoiseFigure.system.configure.generator.initialise.immediate.set() \n
		This command establishes a connection to the external generator. When you send the command, the application configures
		the generator once and turns on its RF output. Note that you have to establish a connection to the generator before you
		can perform the measurement. The command is available with option R&S FSW-B10. \n
		"""
		self._core.io.write(f'SYSTem:CONFigure:GENerator:INITialise:IMMediate')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SYSTem:CONFigure:GENerator:INITialise[:IMMediate] \n
		Snippet: driver.applications.k30NoiseFigure.system.configure.generator.initialise.immediate.set_with_opc() \n
		This command establishes a connection to the external generator. When you send the command, the application configures
		the generator once and turns on its RF output. Note that you have to establish a connection to the generator before you
		can perform the measurement. The command is available with option R&S FSW-B10. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFsw.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SYSTem:CONFigure:GENerator:INITialise:IMMediate', opc_timeout_ms)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LimitCls:
	"""Limit commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("limit", core, parent)

	def get(self, query_range: enums.SelectionRange) -> str:
		"""SCPI: [SENSe]:PULSe:TIMing:PRI:LIMit \n
		Snippet: value: str = driver.applications.k6Pulse.sense.pulse.timing.pri.limit.get(query_range = enums.SelectionRange.ALL) \n
		Returns a comma-separated list of results for the limit check for the specified parameter and number of pulses.
		For details on available parameters see 'Pulse parameters'. The limit check for an individual parameter is defined using
		the CALCulate<n>:TABLe:<ParameterGroup>:<Parameter>:LIMit:STATe commands. Commands for the parameter group <TSIDelobe>
		are only available if the additional option R&S FSW-K6S is installed. \n
			:param query_range: SELected | CURRent | ALL Determines which pulses are checked against the limits SELected Currently selected pulse CURRent Detected pulses in the current capture buffer ALL All detected pulses in the entire measurement.
			:return: check_result: char_data"""
		param = Conversions.enum_scalar_to_str(query_range, enums.SelectionRange)
		response = self._core.io.query_str(f'SENSe:PULSe:TIMing:PRI:LIMit? {param}')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NumeratorCls:
	"""Numerator commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("numerator", core, parent)

	def set(self, value: float, externalGen=repcap.ExternalGen.Nr1) -> None:
		"""SCPI: SOURce:EXTernal<gen>:FREQuency[:FACTor]:NUMerator \n
		Snippet: driver.source.external.frequency.factor.numerator.set(value = 1.0, externalGen = repcap.ExternalGen.Nr1) \n
		This command defines the numerator of the factor with which the analyzer frequency is multiplied to obtain the transmit
		frequency of the selected generator. This command is only valid if External Generator Control (R&S FSW-B10) is installed
		and active. Select the multiplication factor such that the frequency range of the generator is not exceeded if the
		following formula is applied to the start and stop frequency of the analyzer: \n
			:param value: numeric value
			:param externalGen: optional repeated capability selector. Default value: Nr1
		"""
		param = Conversions.decimal_value_to_str(value)
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		self._core.io.write(f'SOURce:EXTernal{externalGen_cmd_val}:FREQuency:FACTor:NUMerator {param}')

	def get(self, externalGen=repcap.ExternalGen.Nr1) -> float:
		"""SCPI: SOURce:EXTernal<gen>:FREQuency[:FACTor]:NUMerator \n
		Snippet: value: float = driver.source.external.frequency.factor.numerator.get(externalGen = repcap.ExternalGen.Nr1) \n
		This command defines the numerator of the factor with which the analyzer frequency is multiplied to obtain the transmit
		frequency of the selected generator. This command is only valid if External Generator Control (R&S FSW-B10) is installed
		and active. Select the multiplication factor such that the frequency range of the generator is not exceeded if the
		following formula is applied to the start and stop frequency of the analyzer: \n
			:param externalGen: optional repeated capability selector. Default value: Nr1
			:return: value: numeric value"""
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		response = self._core.io.query_str(f'SOURce:EXTernal{externalGen_cmd_val}:FREQuency:FACTor:NUMerator?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EattCls:
	"""Eatt commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("eatt", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, attenuation: float, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<Undef>:EATT \n
		Snippet: driver.applications.k149Uwb.inputPy.eatt.set(attenuation = 1.0, inputIx = repcap.InputIx.Default) \n
		This command defines an electronic attenuation manually. Automatic mode must be switched off (INP:EATT:AUTO OFF, see
		method RsFsw.Applications.K18_AmplifierEt.InputPy.Eatt.Auto.set) . If the current reference level is not compatible with
		an attenuation that has been set manually, the command also adjusts the reference level. \n
			:param attenuation: attenuation in dB Range: see data sheet , Unit: DB
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.decimal_value_to_str(attenuation)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:EATT {param}')

	def get(self, inputIx=repcap.InputIx.Default) -> float:
		"""SCPI: INPut<Undef>:EATT \n
		Snippet: value: float = driver.applications.k149Uwb.inputPy.eatt.get(inputIx = repcap.InputIx.Default) \n
		This command defines an electronic attenuation manually. Automatic mode must be switched off (INP:EATT:AUTO OFF, see
		method RsFsw.Applications.K18_AmplifierEt.InputPy.Eatt.Auto.set) . If the current reference level is not compatible with
		an attenuation that has been set manually, the command also adjusts the reference level. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: attenuation: attenuation in dB Range: see data sheet , Unit: DB"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:EATT?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'EattCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EattCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StoreCls:
	"""Store commands group definition. 8 total commands, 6 Subgroups, 0 group commands
	Repeated Capability: Store, default value after init: Store.Pos1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("store", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_store_get', 'repcap_store_set', repcap.Store.Pos1)

	def repcap_store_set(self, store: repcap.Store) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Store.Default
		Default value after init: Store.Pos1"""
		self._cmd_group.set_repcap_enum_value(store)

	def repcap_store_get(self) -> repcap.Store:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def dpd(self):
		"""dpd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dpd'):
			from .Dpd import DpdCls
			self._dpd = DpdCls(self._core, self._cmd_group)
		return self._dpd

	@property
	def ddpd(self):
		"""ddpd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ddpd'):
			from .Ddpd import DdpdCls
			self._ddpd = DdpdCls(self._core, self._cmd_group)
		return self._ddpd

	@property
	def equalizer(self):
		"""equalizer commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_equalizer'):
			from .Equalizer import EqualizerCls
			self._equalizer = EqualizerCls(self._core, self._cmd_group)
		return self._equalizer

	@property
	def mdpd(self):
		"""mdpd commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_mdpd'):
			from .Mdpd import MdpdCls
			self._mdpd = MdpdCls(self._core, self._cmd_group)
		return self._mdpd

	@property
	def iq(self):
		"""iq commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	@property
	def trace(self):
		"""trace commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	def clone(self) -> 'StoreCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = StoreCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: CONFigure:GENerator:MCGD:LEVel:DUTLimit:STATe \n
		Snippet: driver.applications.k17Mcgd.configure.generator.mcgd.level.dutLimit.state.set(state = False) \n
		If activated, the generator does not exceed the maximum input power (peak envelope power, 'PEP') that is currently
		allowed by the DUT. To query or define the current PEP limit value, use method RsFsw.Applications.K17_Mcgd.Configure.
		Generator.Mcgd.Level.DutLimit.set. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CONFigure:GENerator:MCGD:LEVel:DUTLimit:STATe {param}')

	def get(self) -> bool:
		"""SCPI: CONFigure:GENerator:MCGD:LEVel:DUTLimit:STATe \n
		Snippet: value: bool = driver.applications.k17Mcgd.configure.generator.mcgd.level.dutLimit.state.get() \n
		If activated, the generator does not exceed the maximum input power (peak envelope power, 'PEP') that is currently
		allowed by the DUT. To query or define the current PEP limit value, use method RsFsw.Applications.K17_Mcgd.Configure.
		Generator.Mcgd.Level.DutLimit.set. \n
			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
		response = self._core.io.query_str(f'CONFigure:GENerator:MCGD:LEVel:DUTLimit:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StandardCls:
	"""Standard commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("standard", core, parent)

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Catalog import CatalogCls
			self._catalog = CatalogCls(self._core, self._cmd_group)
		return self._catalog

	@property
	def save(self):
		"""save commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_save'):
			from .Save import SaveCls
			self._save = SaveCls(self._core, self._cmd_group)
		return self._save

	def delete(self, standard: str, window=repcap.Window.Default, marker=repcap.Marker.Default, subBlock=repcap.SubBlock.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:POWer<sb>:STANdard:DELete \n
		Snippet: driver.calculate.marker.function.power.standard.delete(standard = '1', window = repcap.Window.Default, marker = repcap.Marker.Default, subBlock = repcap.SubBlock.Default) \n
		This command deletes a file containing an ACLR standard. \n
			:param standard: String containing the file name of the standard.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Power')
		"""
		param = Conversions.value_to_quoted_str(standard)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:POWer{subBlock_cmd_val}:STANdard:DELete {param}')

	def clone(self) -> 'StandardCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = StandardCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PmeterCls:
	"""Pmeter commands group definition. 17 total commands, 8 Subgroups, 0 group commands
	Repeated Capability: PowerMeter, default value after init: PowerMeter.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pmeter", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_powerMeter_get', 'repcap_powerMeter_set', repcap.PowerMeter.Nr1)

	def repcap_powerMeter_set(self, powerMeter: repcap.PowerMeter) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to PowerMeter.Default
		Default value after init: PowerMeter.Nr1"""
		self._cmd_group.set_repcap_enum_value(powerMeter)

	def repcap_powerMeter_get(self) -> repcap.PowerMeter:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def dcycle(self):
		"""dcycle commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dcycle'):
			from .Dcycle import DcycleCls
			self._dcycle = DcycleCls(self._core, self._cmd_group)
		return self._dcycle

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def mtime(self):
		"""mtime commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_mtime'):
			from .Mtime import MtimeCls
			self._mtime = MtimeCls(self._core, self._cmd_group)
		return self._mtime

	@property
	def roffset(self):
		"""roffset commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_roffset'):
			from .Roffset import RoffsetCls
			self._roffset = RoffsetCls(self._core, self._cmd_group)
		return self._roffset

	@property
	def soffset(self):
		"""soffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_soffset'):
			from .Soffset import SoffsetCls
			self._soffset = SoffsetCls(self._core, self._cmd_group)
		return self._soffset

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def trigger(self):
		"""trigger commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def update(self):
		"""update commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_update'):
			from .Update import UpdateCls
			self._update = UpdateCls(self._core, self._cmd_group)
		return self._update

	def clone(self) -> 'PmeterCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PmeterCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ControlCls:
	"""Control commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("control", core, parent)

	def set(self, repetition: enums.HardcopyLogo) -> None:
		"""SCPI: HCOPy:TREPort:ITEM:LOGO:CONTrol \n
		Snippet: driver.hardCopy.treport.item.logo.control.set(repetition = enums.HardcopyLogo.ALWays) \n
		This command selects how often the logo is displayed in the document. \n
			:param repetition: ALWays The logo is displayed at the top of every page of the report. NEVer The logo is displayed on no page of the report. ONCE The logo is displayed on the first page of each dataset.
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.HardcopyLogo)
		self._core.io.write(f'HCOPy:TREPort:ITEM:LOGO:CONTrol {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.HardcopyLogo:
		"""SCPI: HCOPy:TREPort:ITEM:LOGO:CONTrol \n
		Snippet: value: enums.HardcopyLogo = driver.hardCopy.treport.item.logo.control.get() \n
		This command selects how often the logo is displayed in the document. \n
			:return: repetition: ALWays The logo is displayed at the top of every page of the report. NEVer The logo is displayed on no page of the report. ONCE The logo is displayed on the first page of each dataset."""
		response = self._core.io.query_str(f'HCOPy:TREPort:ITEM:LOGO:CONTrol?')
		return Conversions.str_to_scalar_enum(response, enums.HardcopyLogo)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SenseCls:
	"""Sense commands group definition. 347 total commands, 20 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sense", core, parent)

	@property
	def adjust(self):
		"""adjust commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_adjust'):
			from .Adjust import AdjustCls
			self._adjust = AdjustCls(self._core, self._cmd_group)
		return self._adjust

	@property
	def bandwidth(self):
		"""bandwidth commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_bandwidth'):
			from .Bandwidth import BandwidthCls
			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
		return self._bandwidth

	@property
	def correction(self):
		"""correction commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_correction'):
			from .Correction import CorrectionCls
			self._correction = CorrectionCls(self._core, self._cmd_group)
		return self._correction

	@property
	def frequency(self):
		"""frequency commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def iq(self):
		"""iq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Iq import IqCls
			self._iq = IqCls(self._core, self._cmd_group)
		return self._iq

	@property
	def mixer(self):
		"""mixer commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_mixer'):
			from .Mixer import MixerCls
			self._mixer = MixerCls(self._core, self._cmd_group)
		return self._mixer

	@property
	def probe(self):
		"""probe commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_probe'):
			from .Probe import ProbeCls
			self._probe = ProbeCls(self._core, self._cmd_group)
		return self._probe

	@property
	def msra(self):
		"""msra commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_msra'):
			from .Msra import MsraCls
			self._msra = MsraCls(self._core, self._cmd_group)
		return self._msra

	@property
	def rtms(self):
		"""rtms commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rtms'):
			from .Rtms import RtmsCls
			self._rtms = RtmsCls(self._core, self._cmd_group)
		return self._rtms

	@property
	def sweep(self):
		"""sweep commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	@property
	def signal(self):
		"""signal commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_signal'):
			from .Signal import SignalCls
			self._signal = SignalCls(self._core, self._cmd_group)
		return self._signal

	@property
	def measure(self):
		"""measure commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_measure'):
			from .Measure import MeasureCls
			self._measure = MeasureCls(self._core, self._cmd_group)
		return self._measure

	@property
	def statistic(self):
		"""statistic commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_statistic'):
			from .Statistic import StatisticCls
			self._statistic = StatisticCls(self._core, self._cmd_group)
		return self._statistic

	@property
	def mtime(self):
		"""mtime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mtime'):
			from .Mtime import MtimeCls
			self._mtime = MtimeCls(self._core, self._cmd_group)
		return self._mtime

	@property
	def rlength(self):
		"""rlength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rlength'):
			from .Rlength import RlengthCls
			self._rlength = RlengthCls(self._core, self._cmd_group)
		return self._rlength

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRateCls
			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
		return self._symbolRate

	@property
	def window(self):
		"""window commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_window'):
			from .Window import WindowCls
			self._window = WindowCls(self._core, self._cmd_group)
		return self._window

	@property
	def demod(self):
		"""demod commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_demod'):
			from .Demod import DemodCls
			self._demod = DemodCls(self._core, self._cmd_group)
		return self._demod

	@property
	def hop(self):
		"""hop commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_hop'):
			from .Hop import HopCls
			self._hop = HopCls(self._core, self._cmd_group)
		return self._hop

	@property
	def chirp(self):
		"""chirp commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_chirp'):
			from .Chirp import ChirpCls
			self._chirp = ChirpCls(self._core, self._cmd_group)
		return self._chirp

	def clone(self) -> 'SenseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SenseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AverageCls:
	"""Average commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("average", core, parent)

	@property
	def result(self):
		"""result commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_result'):
			from .Result import ResultCls
			self._result = ResultCls(self._core, self._cmd_group)
		return self._result

	def set(self, limit: float, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:BURSt:EVM[:AVERage] \n
		Snippet: driver.applications.k91Wlan.calculate.limit.burst.evm.average.set(limit = 1.0, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command sets or queries the average or maximum error vector magnitude limit determined by the default WLAN
		measurement. For details see 'Modulation accuracy, flatness and tolerance parameters'. This command is only available for
		IEEE 802.11b and g (DSSS) . \n
			:param limit: numeric value in dB The unit for the EVM parameters can be changed in advance using method RsFsw.Applications.K10x_Lte.Unit.Evm.set. Unit: PCT
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.decimal_value_to_str(limit)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:BURSt:EVM:AVERage {param}')

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> float:
		"""SCPI: CALCulate<n>:LIMit<li>:BURSt:EVM[:AVERage] \n
		Snippet: value: float = driver.applications.k91Wlan.calculate.limit.burst.evm.average.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command sets or queries the average or maximum error vector magnitude limit determined by the default WLAN
		measurement. For details see 'Modulation accuracy, flatness and tolerance parameters'. This command is only available for
		IEEE 802.11b and g (DSSS) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: limit: numeric value in dB The unit for the EVM parameters can be changed in advance using method RsFsw.Applications.K10x_Lte.Unit.Evm.set. Unit: PCT"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:BURSt:EVM:AVERage?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'AverageCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AverageCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, color_scheme: enums.FftWindowTypeK60) -> None:
		"""SCPI: [SENSe]:SWEep:FFT:WINDow:TYPE \n
		Snippet: driver.applications.k60Transient.sense.sweep.fft.window.typePy.set(color_scheme = enums.FftWindowTypeK60.BLACkharris) \n
		This command queries or sets the FFT windowing function. \n
			:param color_scheme: BLACkharris | CHEByshev | FLATtop | GAUSsian | HAMMing | HANNing | RECTangular
		"""
		param = Conversions.enum_scalar_to_str(color_scheme, enums.FftWindowTypeK60)
		self._core.io.write(f'SENSe:SWEep:FFT:WINDow:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FftWindowTypeK60:
		"""SCPI: [SENSe]:SWEep:FFT:WINDow:TYPE \n
		Snippet: value: enums.FftWindowTypeK60 = driver.applications.k60Transient.sense.sweep.fft.window.typePy.get() \n
		This command queries or sets the FFT windowing function. \n
			:return: color_scheme: BLACkharris | CHEByshev | FLATtop | GAUSsian | HAMMing | HANNing | RECTangular"""
		response = self._core.io.query_str(f'SENSe:SWEep:FFT:WINDow:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.FftWindowTypeK60)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Types import DataType
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ItemCls:
	"""Item commands group definition. 4 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("item", core, parent)

	@property
	def maccuracy(self):
		"""maccuracy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_maccuracy'):
			from .Maccuracy import MaccuracyCls
			self._maccuracy = MaccuracyCls(self._core, self._cmd_group)
		return self._maccuracy

	@property
	def power(self):
		"""power commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def vcurrent(self):
		"""vcurrent commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_vcurrent'):
			from .Vcurrent import VcurrentCls
			self._vcurrent = VcurrentCls(self._core, self._cmd_group)
		return self._vcurrent

	def set(self, item: enums.TableItem, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:STABle:ITEM \n
		Snippet: driver.applications.k18AmplifierEt.display.window.stable.item.set(item = enums.TableItem.ADRoop, state = False, window = repcap.Window.Default) \n
		This command adds and removes results from the statistics table. \n
			:param item: Selects the result. See the table in the desription of method RsFsw.Applications.K91_Wlan.Display.Window.Table.Item.set for a list of available parameters.
			:param state: ON | OFF | 1 | 0
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('item', item, DataType.Enum, enums.TableItem), ArgSingle('state', state, DataType.Boolean))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:STABle:ITEM {param}'.rstrip())

	def get(self, item: enums.TableItem, window=repcap.Window.Default) -> bool:
		"""SCPI: DISPlay[:WINDow<n>]:STABle:ITEM \n
		Snippet: value: bool = driver.applications.k18AmplifierEt.display.window.stable.item.get(item = enums.TableItem.ADRoop, window = repcap.Window.Default) \n
		This command adds and removes results from the statistics table. \n
			:param item: Selects the result. See the table in the desription of method RsFsw.Applications.K91_Wlan.Display.Window.Table.Item.set for a list of available parameters.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: state: ON | OFF | 1 | 0"""
		param = Conversions.enum_scalar_to_str(item, enums.TableItem)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:STABle:ITEM? {param}')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'ItemCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ItemCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:TABLe:TSIDelobe:SDELay:LIMit:STATe \n
		Snippet: driver.applications.k6Pulse.calculate.table.tsidelobe.sdelay.limit.state.set(state = False, window = repcap.Window.Default) \n
		Activates or deactivates a limit check for the selected parameter.
		The limits are defined using CALCulate<n>:TABLe:<ParameterGroup>:<Parameter>:LIMit. Commands for the parameter group
		<TSIDelobe> are only available if the additional option R&S FSW-K6S is installed. \n
			:param state: ON | OFF | 1 | 0
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:TABLe:TSIDelobe:SDELay:LIMit:STATe {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: CALCulate<n>:TABLe:TSIDelobe:SDELay:LIMit:STATe \n
		Snippet: value: bool = driver.applications.k6Pulse.calculate.table.tsidelobe.sdelay.limit.state.get(window = repcap.Window.Default) \n
		Activates or deactivates a limit check for the selected parameter.
		The limits are defined using CALCulate<n>:TABLe:<ParameterGroup>:<Parameter>:LIMit. Commands for the parameter group
		<TSIDelobe> are only available if the additional option R&S FSW-K6S is installed. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: state: ON | OFF | 1 | 0"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:TABLe:TSIDelobe:SDELay:LIMit:STATe?')
		return Conversions.str_to_bool(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RangeCls:
	"""Range commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("range", core, parent)

	def set(self, range_py: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:STATistics:SCALe:X:RANGe \n
		Snippet: driver.calculate.statistics.scale.x.range.set(range_py = 1.0, window = repcap.Window.Default) \n
		This command defines the display range of the x-axis for statistical measurements. The effects are identical to method
		RsFsw.Display.Window.Subwindow.Trace.Y.Scale.set. \n
			:param range_py: Range: 1 dB to 200 dB, Unit: dB
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(range_py)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:STATistics:SCALe:X:RANGe {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:STATistics:SCALe:X:RANGe \n
		Snippet: value: float = driver.calculate.statistics.scale.x.range.get(window = repcap.Window.Default) \n
		This command defines the display range of the x-axis for statistical measurements. The effects are identical to method
		RsFsw.Display.Window.Subwindow.Trace.Y.Scale.set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: range_py: Range: 1 dB to 200 dB, Unit: dB"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:STATistics:SCALe:X:RANGe?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScsCls:
	"""Scs commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scs", core, parent)

	def set(self, subcarrier_spacing: enums.SubcarrierSpacingNr5G, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:NR5G]:UL[:CC<cc>]:PRACh:SCS \n
		Snippet: driver.applications.k14Xnr5G.configure.nr5G.uplink.cc.prach.scs.set(subcarrier_spacing = enums.SubcarrierSpacingNr5G.SS1_25, carrierComponent = repcap.CarrierComponent.Default) \n
		This command select the subcarrier spacing of the PRACH. \n
			:param subcarrier_spacing: SS1_25 | SS5 | SS15 | SS30 | SS60 | SS120 | SS480 | SS960 The availability of subcarrier spacings depends on the selected deployment and PRACH format (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.DfRange.set and method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Prach.FormatPy.set) .
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.enum_scalar_to_str(subcarrier_spacing, enums.SubcarrierSpacingNr5G)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:NR5G:UL:CC{carrierComponent_cmd_val}:PRACh:SCS {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> enums.SubcarrierSpacingNr5G:
		"""SCPI: CONFigure[:NR5G]:UL[:CC<cc>]:PRACh:SCS \n
		Snippet: value: enums.SubcarrierSpacingNr5G = driver.applications.k14Xnr5G.configure.nr5G.uplink.cc.prach.scs.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command select the subcarrier spacing of the PRACH. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: subcarrier_spacing: SS1_25 | SS5 | SS15 | SS30 | SS60 | SS120 | SS480 | SS960 The availability of subcarrier spacings depends on the selected deployment and PRACH format (method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.DfRange.set and method RsFsw.Applications.K14x_Nr5G.Configure.Nr5G.Uplink.Cc.Prach.FormatPy.set) ."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:NR5G:UL:CC{carrierComponent_cmd_val}:PRACh:SCS?')
		return Conversions.str_to_scalar_enum(response, enums.SubcarrierSpacingNr5G)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MemoryallCls:
	"""Memoryall commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("memoryall", core, parent)

	def get(self) -> List[float]:
		"""SCPI: TRACe:IQ:DATA:MEMory \n
		Snippet: value: List[float] = driver.applications.k149Uwb.trace.iq.data.memoryall.get() \n
		No command help available \n
			:return: iq_data: No help available"""
		response = self._core.io.query_bin_or_ascii_float_list(f'FORMAT REAL,32;TRACe:IQ:DATA:MEMory?')
		return response



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqCls:
	"""Iq commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iq", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def formatPy(self):
		"""formatPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_formatPy'):
			from .FormatPy import FormatPyCls
			self._formatPy = FormatPyCls(self._core, self._cmd_group)
		return self._formatPy

	@property
	def range(self):
		"""range commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_range'):
			from .Range import RangeCls
			self._range = RangeCls(self._core, self._cmd_group)
		return self._range

	@property
	def comment(self):
		"""comment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_comment'):
			from .Comment import CommentCls
			self._comment = CommentCls(self._core, self._cmd_group)
		return self._comment

	def clone(self) -> 'IqCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IqCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	def set(self, unit: enums.PowerUnit) -> None:
		"""SCPI: UNIT:POWer \n
		Snippet: driver.unit.power.set(unit = enums.PowerUnit.A) \n
		This command selects the unit of the y-axis. The unit applies to all power-based measurement windows with absolute values. \n
			:param unit: DBM | V | A | W | DBPW | WATT | DBUV | DBMV | VOLT | DBUA | AMPere | DBM_mhz | DBM_hz | DBUa_mhz | DBUV_mhz | DBmV_mhz | DBpW_mhz (Units based on 1 MHz require installed R&S FSW-K54 (EMI measurements) option.)
		"""
		param = Conversions.enum_scalar_to_str(unit, enums.PowerUnit)
		self._core.io.write(f'UNIT:POWer {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PowerUnit:
		"""SCPI: UNIT:POWer \n
		Snippet: value: enums.PowerUnit = driver.unit.power.get() \n
		This command selects the unit of the y-axis. The unit applies to all power-based measurement windows with absolute values. \n
			:return: unit: DBM | V | A | W | DBPW | WATT | DBUV | DBMV | VOLT | DBUA | AMPere | DBM_mhz | DBM_hz | DBUa_mhz | DBUV_mhz | DBmV_mhz | DBpW_mhz (Units based on 1 MHz require installed R&S FSW-K54 (EMI measurements) option.)"""
		response = self._core.io.query_str(f'UNIT:POWer?')
		return Conversions.str_to_scalar_enum(response, enums.PowerUnit)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FullCls:
	"""Full commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("full", core, parent)

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> List[float]:
		"""SCPI: CALCulate<n>:LIMit<li>:UPPer:FULL \n
		Snippet: value: List[float] = driver.applications.k91Wlan.calculate.limit.upper.full.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command queries the limit line y-values as defined by the standard for the specified window. Tip: to query the
		corresponding x-values, use the method RsFsw.Trace.Data.X.get_ command. Note: both commands have the same effect; the
		suffix determines whether the upper or lower limit is returned. For compatibility reasons, both commands are maintained. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: limit_values: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_bin_or_ascii_float_list(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:UPPer:FULL?')
		return response



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AcPairsCls:
	"""AcPairs commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("acPairs", core, parent)

	def set(self, count: float) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:ACPairs \n
		Snippet: driver.applications.k18AmplifierEt.sense.power.achannel.acPairs.set(count = 1.0) \n
		This command defines the number of pairs of adjacent and alternate channels. \n
			:param count: Range: 0 to 12
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'SENSe:POWer:ACHannel:ACPairs {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:POWer:ACHannel:ACPairs \n
		Snippet: value: float = driver.applications.k18AmplifierEt.sense.power.achannel.acPairs.get() \n
		This command defines the number of pairs of adjacent and alternate channels. \n
			:return: count: No help available"""
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:ACPairs?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Types import DataType
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FparametersCls:
	"""Fparameters commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fparameters", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	def set(self, result: enums.ResultTypeNr5G, condition: enums.EventFilterCondition = None, value: float = None) -> None:
		"""SCPI: [SENSe]:NR5G:EFILter:FPARameters \n
		Snippet: driver.applications.k14Xnr5G.sense.nr5G.efilter.fparameters.set(result = enums.ResultTypeNr5G.AAPFail, condition = enums.EventFilterCondition.FAILed, value = 1.0) \n
		This command defines a filter condition for the event filter in combined measurements. \n
			:param result: SSTate | APFail | AAPFail | ARPFail | SPFail | MID | TSTamp | TSDelta | EVM | POWer | DSQP | DSST | DSSF | DSTS | FSOFfset | PCHannel | PSIGnal | FERRor | SERRor | IQOFfset | GIMBalance | QUADrature | OSTP | RSTP | RSSI | CSIPower | SSPower | CRESt | OVLD | MODulation | NORB | BLER | TPUT Selects the result that you want to define a filter for.
			:param condition: FAILed Filter condition: test failed (for boolean results only) . GTEQual Filter condition: greater than or equal (for numerical results only) . LTEQual Filter condition: lower than or equal (for numerical results only) . PASSed Filter condition: test passed (for boolean results only) .
			:param value: For numerical results only.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('result', result, DataType.Enum, enums.ResultTypeNr5G), ArgSingle('condition', condition, DataType.Enum, enums.EventFilterCondition, is_optional=True), ArgSingle('value', value, DataType.Float, None, is_optional=True))
		self._core.io.write(f'SENSe:NR5G:EFILter:FPARameters {param}'.rstrip())

	# noinspection PyTypeChecker
	class FparametersStruct(StructBase):
		"""Response structure. Fields: \n
			- Result: enums.ResultTypeNr5G: SSTate | APFail | AAPFail | ARPFail | SPFail | MID | TSTamp | TSDelta | EVM | POWer | DSQP | DSST | DSSF | DSTS | FSOFfset | PCHannel | PSIGnal | FERRor | SERRor | IQOFfset | GIMBalance | QUADrature | OSTP | RSTP | RSSI | CSIPower | SSPower | CRESt | OVLD | MODulation | NORB | BLER | TPUT Selects the result that you want to define a filter for.
			- Condition: enums.EventFilterCondition: FAILed Filter condition: test failed (for boolean results only) . GTEQual Filter condition: greater than or equal (for numerical results only) . LTEQual Filter condition: lower than or equal (for numerical results only) . PASSed Filter condition: test passed (for boolean results only) .
			- Value: float: For numerical results only."""
		__meta_args_list = [
			ArgStruct.scalar_enum('Result', enums.ResultTypeNr5G),
			ArgStruct.scalar_enum('Condition', enums.EventFilterCondition),
			ArgStruct.scalar_float('Value')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Result: enums.ResultTypeNr5G = None
			self.Condition: enums.EventFilterCondition = None
			self.Value: float = None

	def get(self) -> FparametersStruct:
		"""SCPI: [SENSe]:NR5G:EFILter:FPARameters \n
		Snippet: value: FparametersStruct = driver.applications.k14Xnr5G.sense.nr5G.efilter.fparameters.get() \n
		This command defines a filter condition for the event filter in combined measurements. \n
			:return: structure: for return value, see the help for FparametersStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:NR5G:EFILter:FPARameters?', self.__class__.FparametersStruct())

	def clone(self) -> 'FparametersCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FparametersCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LengthCls:
	"""Length commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("length", core, parent)

	def set(self, samples: float) -> None:
		"""SCPI: [SENSe]:SWEep:LENGth \n
		Snippet: driver.applications.k18AmplifierEt.sense.sweep.length.set(samples = 1.0) \n
		This command defines the capture length.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn off automatic selection of the capture time ([SENSe:]SWEep:TIME:AUTO) .
			INTRO_CMD_HELP: Effects of this command \n
			- Changing the capture length automatically adjusts the capture time. \n
			:param samples: numeric value: (integer only) Unit: Samples
		"""
		param = Conversions.decimal_value_to_str(samples)
		self._core.io.write(f'SENSe:SWEep:LENGth {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:LENGth \n
		Snippet: value: float = driver.applications.k18AmplifierEt.sense.sweep.length.get() \n
		This command defines the capture length.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn off automatic selection of the capture time ([SENSe:]SWEep:TIME:AUTO) .
			INTRO_CMD_HELP: Effects of this command \n
			- Changing the capture length automatically adjusts the capture time. \n
			:return: samples: numeric value: (integer only) Unit: Samples"""
		response = self._core.io.query_str(f'SENSe:SWEep:LENGth?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NgParameterCls:
	"""NgParameter commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ngParameter", core, parent)

	def set(self, ng_method: enums.NgMethod, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:LTE]:DL[:CC<cc>]:PHICh:NGParameter \n
		Snippet: driver.applications.k10Xlte.configure.lte.downlink.cc.phich.ngParameter.set(ng_method = enums.NgMethod.AUTO, carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the method that determines the number of PHICH groups in a subframe. \n
			:param ng_method: No help available
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.enum_scalar_to_str(ng_method, enums.NgMethod)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:LTE:DL:CC{carrierComponent_cmd_val}:PHICh:NGParameter {param}')

	# noinspection PyTypeChecker
	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> enums.NgMethod:
		"""SCPI: CONFigure[:LTE]:DL[:CC<cc>]:PHICh:NGParameter \n
		Snippet: value: enums.NgMethod = driver.applications.k10Xlte.configure.lte.downlink.cc.phich.ngParameter.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the method that determines the number of PHICH groups in a subframe. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: ng_method: No help available"""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:LTE:DL:CC{carrierComponent_cmd_val}:PHICh:NGParameter?')
		return Conversions.str_to_scalar_enum(response, enums.NgMethod)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:SUMMary:MEAN:PHOLd:RESult \n
		Snippet: value: float = driver.calculate.marker.function.summary.mean.phold.result.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the maximum mean time domain power. The query is only possible if the peak hold function has been
		activated previously using method RsFsw.Calculate.Marker.Function.Summary.Phold.set. To get a valid result, you have to
		perform a complete measurement with synchronization to the end of the measurement before reading out the result. This is
		only possible for single sweep mode. See also method RsFsw.Applications.K10x_Lte.Initiate.Continuous.set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: mean_power: Mean power of the signal during the measurement time."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:SUMMary:MEAN:PHOLd:RESult?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CoeficientsCls:
	"""Coeficients commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coeficients", core, parent)

	def get(self) -> int:
		"""SCPI: FETCh:BURSt:AM:AM:COEFicients \n
		Snippet: value: int = driver.applications.k91Wlan.fetch.burst.am.am.coeficients.get() \n
		This remote control returns the coefficients of the polynomial regression model used to determine the 'AM/AM' result
		display. See 'AM/AM' for details. \n
			:return: coefficients: No help available"""
		response = self._core.io.query_str(f'FETCh:BURSt:AM:AM:COEFicients?')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EndCls:
	"""End commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("end", core, parent)

	def set(self, time: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:CHRDetection:POWer:OFFSet:END \n
		Snippet: driver.applications.k60Transient.calculate.chrDetection.power.offset.end.set(time = 1.0, window = repcap.Window.Default) \n
		Defines the end of the measurement range for power results as an offset in seconds from the chirp end. This command is
		only available if the reference is EDGE (see method RsFsw.Applications.K60_Transient.Calculate.ChrDetection.Power.
		Reference.set) . For details on the measurement range parameters see 'Measurement range'. \n
			:param time: Unit: S
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(time)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:CHRDetection:POWer:OFFSet:END {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:CHRDetection:POWer:OFFSet:END \n
		Snippet: value: float = driver.applications.k60Transient.calculate.chrDetection.power.offset.end.get(window = repcap.Window.Default) \n
		Defines the end of the measurement range for power results as an offset in seconds from the chirp end. This command is
		only available if the reference is EDGE (see method RsFsw.Applications.K60_Transient.Calculate.ChrDetection.Power.
		Reference.set) . For details on the measurement range parameters see 'Measurement range'. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: time: Unit: S"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:CHRDetection:POWer:OFFSet:END?')
		return Conversions.str_to_float(response)
